#!/bin/bash

set -e

# Get current version
current_version=$(jq -r '.version' package.json)
echo "Current version: $current_version"

# Determine new version (example: increment patch)
IFS='.' read -r major minor patch <<< "$current_version"
new_patch=$((patch + 1))
new_version="$major.$minor.$new_patch"
echo "New version: $new_version"

# Update package.json
jq ".version = \"$new_version\"" package.json > temp.json && mv temp.json package.json

# Optional: Commit and tag

echo ${ secrets.PACKAGES_USER }
git config --global user.name ${{ secrets.PACKAGES_USER }}
git add package.json
echo "adding succeeded"
git commit -m "Bump version to $new_version"
echo "commiting succeeded"
git tag -a "v$new_version" -m "Release version $new_version"
echo "tagging succeeded"
git remote -v
git push main HEAD --tags
echo "pushing succeeded"